@@ -5,38 +5,36 @@ package Protocol::Modbus::Transport::Serial;
 use strict;
 use base 'Protocol::Modbus::Transport';
 use Carp ();
-use Device::SerialPort;       # TODO Win32::SerialPort for windows machines
+use Device::SerialPort;    # TODO Win32::SerialPort for windows machines
 
-sub connect
-{
+sub connect {
     my $self = $_[0];
     my $comm;
     my $opt = $self->options();
 
-    if( ! exists $opt->{port} || ! $opt->{port} )
-    {
+    if (!exists $opt->{port} || !$opt->{port}) {
         croak('Modbus Serial transport error: no \'port\' parameter supplied.');
     }
 
-    if( ! $self->connected )
-    {
-        if( ! ($comm = Device::SerialPort->new($opt->{port}) )
-        {
-            Carp::croak('Modbus Serial transport error: can\'t open port ' . $opt->{port});
-            return(0);
+    if (!$self->connected) {
+        if (!($comm = Device::SerialPort->new($opt->{port}))) {
+            Carp::croak(
+                'Modbus Serial transport error: can\'t open port ' . $opt->{port});
+            return (0);
         }
 
         my $ok = $comm->connect(
-            baudrate=>$opt->{baudrate} || 9600,
-            databits=>$opt->{databits} || 8,
-            stopbits=>exists $opt->{stopbits} ? $opt->{stopbits} : 1,
-            parity  =>$opt->{parity}   || 'none'
+            baudrate => $opt->{baudrate} || 9600,
+            databits => $opt->{databits} || 8,
+            stopbits => exists $opt->{stopbits} ? $opt->{stopbits} : 1,
+            parity => $opt->{parity} || 'none'
         );
 
-        if( ! $ok )
-        {
-            Carp::croak('Modbus Serial transport error: can\'t connect to Modbus server on port ' . $opt->{port});
-            return(0);
+        if (!$ok) {
+            Carp::croak(
+                'Modbus Serial transport error: can\'t connect to Modbus server on port '
+                    . $opt->{port});
+            return (0);
         }
 
         # Purge RX/TX buffers
@@ -46,24 +44,21 @@ sub connect
         $self->{_handle} = $comm;
 
     }
-    else
-    {
+    else {
         $comm = $self->{_handle};
     }
 
-    return($comm ? 1 : 0);
+    return ($comm ? 1 : 0);
 }
 
-sub connected
-{
+sub connected {
     my $self = $_[0];
     return $self->{_handle};
 }
 
 # Send request object
-sub send
-{
-    my($self, $req) = @_;
+sub send {
+    my ($self, $req) = @_;
 
     my $comm = $self->{_handle};
     return undef unless $comm;
@@ -72,22 +67,21 @@ sub send
     my $ok = $comm->write($req->pdu());
     select(undef, undef, undef, 0.10);
 
-    return($ok);
+    return ($ok);
 }
 
-sub receive
-{
-    my($self, $req) = @_;
+sub receive {
+    my ($self, $req) = @_;
 
     # Get port channel
     my $comm = $self->{_handle};
     my $data = $comm->read(100);
+
     #warn('Received: [' . unpack('H*', $data) . ']');
-    return($data);
+    return ($data);
 }
 
-sub disconnect
-{
+sub disconnect {
     my $self = $_[0];
     my $comm = $self->{_handle};
     return unless $comm;
